package com.caimei.controller;

import com.caimei.model.ResponseJson;
import com.caimei.service.OrderSubmitService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/3/21
 */
@Api(tags = "订单结算")
@Slf4j
@RestController
@RequestMapping("/order")
public class OrderSubmitApi {

    private OrderSubmitService orderSubmitService;

    @Autowired
    public void setOrderSubmitService(OrderSubmitService orderSubmitService) {
        this.orderSubmitService = orderSubmitService;
    }

    /**
     * 商品结算（普通商品和二手商品通用接口）
     * <p>
     * 返回参数：shopList：按照供应商分类的商品信息
     * invoice：发票信息(目前你应该用不到，适用crm端)
     * userMoney：用户余额
     * postage：邮费（-1到付，0包邮，大于0具体金额）
     */
    @ApiOperation("商品结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productIds", value = "组织商品ID串用逗号隔开。", required = true),
            @ApiImplicitParam(name = "count", value = "立即购买商品数量，购物车count为null。"),
            @ApiImplicitParam(name = "userId", value = "机构用户id。", required = true)
    })
    @GetMapping("/confirm")
    public ResponseJson<Map<String, Object>> orderConfirm(String productIds, Integer count, Integer userId) {
        return orderSubmitService.orderConfirm(productIds, count, userId);
    }
}
