package com.caimei.service.impl;

import com.caimei.mapper.OrderSubmitMapper;
import com.caimei.mapper.ProductMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.CmUserInvoiceInfoPo;
import com.caimei.model.po.PromotionsPo;
import com.caimei.model.vo.CartProductVo;
import com.caimei.model.vo.ShopVo;
import com.caimei.service.OrderSubmitService;
import com.caimei.service.ShoppingCartService;
import com.caimei.util.MathUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/3/21
 */
@Slf4j
@Service
public class OrderSubmitServiceImpl implements OrderSubmitService {
    @Resource
    private OrderSubmitMapper orderSubmitMapper;
    @Resource
    private ShoppingCartService shoppingCartService;

    @Override
    public ResponseJson<Map<String, Object>> orderConfirm(String productIds, Integer count, Integer userId) {
        Map<String, Object> confirmData = new HashMap<>(5);
        if (userId != null) {
            log.info("<<<<< 结算订单 >>>>>");
            //商品总金额
            AtomicReference<BigDecimal> totalPrice = new AtomicReference<BigDecimal>(BigDecimal.ZERO);
            String[] productId = productIds.split(",");
            List<Integer> shopIds = new ArrayList<>();
            List<CartProductVo> productGifts = new ArrayList<>();
            List<ShopVo> shopList = orderSubmitMapper.findShopByproductIds(productId);
            shopList.forEach(shop -> {
                shopIds.add(shop.getShopId());
                List<CartProductVo> products = new ArrayList<>();
                if (null == count) {
                    //购物车购买
                    products = orderSubmitMapper.findProductListByCart(shop.getShopId(), productId);
                } else {
                    //直接立即购买
                    products.add(orderSubmitMapper.findCartByProductId(productId[0]));
                    products.get(0).setProductCount(count);
                }
                BigDecimal shopTotalPrice = BigDecimal.ZERO;
                for (CartProductVo product : products) {
                    productGifts.addAll(shoppingCartService.setProductPrice(product));
                    shopTotalPrice = MathUtil.add(shopTotalPrice, product.getRetailPrice());
                }
                shop.setShopTotalPrice(shopTotalPrice);
                shop.setProductList(products);
                totalPrice.set(MathUtil.add(totalPrice.get(), shopTotalPrice));
            });
            //单品满赠
            if (productGifts.size() > 0) {
                for (CartProductVo productGift : productGifts) {
                    if (shopIds.contains(productGift.getShopId())) {
                        shopList.forEach(shop -> {
                            if (productGift.getShopId().equals(shop.getShopId())) {
                                shop.getProductList().add(productGift);
                            }
                        });
                    } else {
                        ShopVo shop = orderSubmitMapper.getShop(productGift.getShopId());
                        List<CartProductVo> list = new ArrayList<>();
                        list.add(productGift);
                        shop.setProductList(list);
                        shopList.add(shop);
                        shopIds.add(shop.getShopId());
                    }
                }
            }
            confirmData.put("totalPrice", totalPrice);
            confirmData.put("shopList", shopList);
            // 发票信息
            CmUserInvoiceInfoPo invoice = orderSubmitMapper.findUserInvoice(userId);
            confirmData.put("invoice", invoice);
            return ResponseJson.success(confirmData);
        } else {
            return ResponseJson.error("登录后才能购买", null);
        }
    }
}
